@@ -36,7 +36,6 @@ class QDomElement;
 class QIcon;
 class QPoint;
 class QString;
-class QStringList;
 template<class T> class QList;
 
 namespace Akregator {
@@ -151,7 +150,7 @@ public:
 
     /**
     @param doNotify notification on changes on/off flag
-    @param notifyOccurredChanges notify changes occurred while turn off when set to true again */
+    */
 
     virtual void setNotificationMode(bool doNotify);
 
@@ -161,7 +160,7 @@ public:
     virtual const TreeNode *next() const = 0;
     virtual TreeNode *next() = 0;
 
-    /** returns the ID of this node. IDs are managed by @ref FeedList objects and must be unique within the list. Some IDs have a special meaning:
+    /** returns the ID of this node. IDs are managed by FeedList objects and must be unique within the list. Some IDs have a special meaning:
     @c 0 is the default value and indicates that no ID was set
     @c 1 is reserved for the "All Feeds" root node */
     virtual uint id() const;
@@ -177,8 +176,9 @@ public:
 public Q_SLOTS:
 
     /** adds node to a fetch queue
-        @param intervalFetchesOnly */
-
+        @param queue pointer to the queue
+        @param intervalFetchesOnly determines whether to allow only interval fetches
+    */
     virtual void slotAddToFetchQueue(Akregator::FetchQueue *queue, bool intervalFetchesOnly = false) = 0;
 
 Q_SIGNALS:
@@ -191,7 +191,7 @@ Q_SIGNALS:
 
     /** emitted when new articles were added to this node or any node in the subtree (for folders). Note that this has nothing to do with fetching, the article might have been moved from somewhere else in the tree into this subtree, e.g. by moving the feed the article is in.
         @param TreeNode* the node articles were added to
-        @param QStringList the guids of the articles added
+        @param guids the guids of the articles added
     */
     void signalArticlesAdded(Akregator::TreeNode *, const QVector<Akregator::Article> &guids);
 
