@@ -21,6 +21,7 @@
 #include <KLocalizedString>
 #include <QAction>
 #include <QIcon>
+#include <QKeyEvent>
 #include <QMenu>
 
 using namespace Akregator;
@@ -37,6 +38,15 @@ StatusSearchLine::~StatusSearchLine()
 {
 }
 
+void StatusSearchLine::keyPressEvent(QKeyEvent *e)
+{
+    if (e->key() == Qt::Key_Escape) {
+        Q_EMIT forceLostFocus();
+    } else {
+        KLineEdit::keyPressEvent(e);
+    }
+}
+
 void StatusSearchLine::initializeHash()
 {
     const QIcon iconAll = QIcon::fromTheme(QStringLiteral("system-run"));
